###
API
###

Core
====

.. automodapi:: jdaviz.core.events
   :no-inheritance-diagram:

.. automodapi:: jdaviz.core.registries
   :no-inheritance-diagram:

.. automodapi:: jdaviz.core.template_mixin
   :no-inheritance-diagram:


Application
===========

.. automodapi:: jdaviz.app
   :no-inheritance-diagram:

Configurations
==============

.. automodapi:: jdaviz.configs.default.plugins
   :no-inheritance-diagram:

.. automodapi:: jdaviz.configs.cubeviz.plugins
   :no-inheritance-diagram:
